The structured_map macro allows users of the macro to generate structured
maps with a known and finite set of keys that they can perform map functions
on such as map, zip, iter and much more.
The structured_map macro allows users of the macro to generate structured
maps with a known and finite set of keys that they can perform map functions
on such as map, zip, iter and much more.